pypret.pulse module
===================

.. automodule:: pypret.pulse
    :members:
    :undoc-members:
    :show-inheritance:
    
.. autofunction:: pypret.random_pulse.random_pulse

.. autofunction:: pypret.random_pulse.random_gaussian
